Author: akhaldi
Date: Sat Apr 25 10:51:25 2015
New Revision: 67392
URL:
http://svn.reactos.org/svn/reactos?rev=67392&view=rev
Log:
[RSAENH] Sync with Wine Staging 1.7.37. CORE-9246
Modified:
trunk/reactos/dll/win32/rsaenh/rsaenh.c
trunk/reactos/media/doc/README.WINE
Modified: trunk/reactos/dll/win32/rsaenh/rsaenh.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/rsaenh/rsaenh.c?…
==============================================================================
--- trunk/reactos/media/doc/README.WINE [iso-8859-1] (original)
+++ trunk/reactos/media/doc/README.WINE [iso-8859-1] Sat Apr 25 10:51:25 2015
@@ -168,7 +168,7 @@
reactos/dll/win32/riched32 # Synced to Wine-1.7.27
reactos/dll/win32/rpcrt4 # Synced to Wine-1.7.17
reactos/dll/win32/rsabase # Synced to Wine-1.7.27
-reactos/dll/win32/rsaenh # Synced to Wine-1.7.27
+reactos/dll/win32/rsaenh # Synced to WineStaging-1.7.37
reactos/dll/win32/sccbase # Synced to Wine-1.7.27
reactos/dll/win32/schannel # Synced to Wine-1.7.27
reactos/dll/win32/scrrun # Synced to Wine-1.7.27
--- trunk/reactos/dll/win32/rsaenh/rsaenh.c [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/rsaenh/rsaenh.c [iso-8859-1] Sat Apr 25 10:51:25 2015
@@ -3466,6 +3466,8 @@
switch (pCryptKey->aiAlgid) {
case CALG_RC2:
case CALG_RC4:
+ {
+ KEYCONTAINER *pKeyContainer =
get_key_container(pCryptKey->hProv);
if (!pbData)
{
SetLastError(ERROR_INVALID_PARAMETER);
@@ -3478,11 +3480,13 @@
pbData, 11);
pCryptKey->dwSaltLen = 11;
setup_key(pCryptKey);
- /* Strange but true: salt length reset to 0 after setting
- * it via KP_SALT.
- */
- pCryptKey->dwSaltLen = 0;
+ /* After setting the salt value if the provider is not base or
+ * strong the salt length will be reset. */
+ if (pKeyContainer->dwPersonality != RSAENH_PERSONALITY_BASE
&&
+ pKeyContainer->dwPersonality != RSAENH_PERSONALITY_STRONG)
+ pCryptKey->dwSaltLen = 0;
break;
+ }
default:
SetLastError(NTE_BAD_KEY);
return FALSE;
Modified: trunk/reactos/media/doc/README.WINE
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/media/doc/README.WINE?rev=…
==============================================================================